use strict;
use warnings FATAL => 'all';

use HTML::Zoom;
use Test::More;

ok my $zoom = HTML::Zoom->from_html(<<HTML);
<html>
  <head>
    <title>Hi!</title>
  </head>
  <body id="content-area">
    <h1>Test</h1>
    <div>
      <p class="first-para">Some Stuff</p>
      <p class="body-para">More Stuff</p>
      <p class="body-para">Even More Stuff</p>
      <ol>
        <li class="first-item odd">First</li>
        <li class="body-items even">Stuff A</li>
        <li class="body-items odd">Stuff B</li>
        <li class="body-items even">Stuff C</li>
        <li class="last-item odd">Last</li>
      </ol>
      <ul class="items">
        <li>space</li>
      </ul>
      <p class="body-para">Even More stuff</p>
      <p class="last-para">Some Stuff</p>
    </div>
    <p id="footer">Copyright 2222</p>
  </body>
</html>
HTML

ok ! eval { $zoom->ressplace_content('.first-param' => 'First!'); 1},
  'Properly die on bad method';

ok my $html = $zoom
  ->replace_content('.first-para' => 'First!')
  ->replace_content('.last-para' => 'Last!')
  ->prepend_content(
    '.first-item' => [{type=>'TEXT', raw=>'FIRST: '}],
    '.last-item' => [{type=>'TEXT', raw=>'LAST: '}],
  )
  ->fill('.odd' => 'IS ODD')
  ->fill('.items' => [
        sub { $_->select('li')->replace_content("XXX")},
        sub { $_->select('li')->replace_content("YYY")},
        sub { $_->select('li')->replace_content("ZZZ", "000")},
  ])
  ->to_html;

warn $html;

done_testing;
